
FORMAT = {
	"instance": {
		"hostName": "",
		"app": "",
		"instanceId": "",
		"vipAddress": "",
		"secureVipAddress": "",
		"ipAddr": "",
		"status": "",
		"port": {"$": "", "@enabled": ""},
		"securePort": {"$": "", "@enabled": ""},
		"healthCheckUrl": "",
		"statusPageUrl": "",
		"homePageUrl": "",
		"dataCenterInfo": {
			"@class": "",
			"name": ""
		}
	}
}
